# Copyright (c) IBM
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
Base Credential Object Class

This module defines the Credential class. The Credential class is the base
class to represent all credentials which a KeyMaster can use for
authenticating.
"""

import abc


class Credential(object, metaclass=abc.ABCMeta):
    """Base class to represent all credentials."""

    def __init__(self):
        pass
